@@ -281,7 +281,7 @@ omxCheckWarning(mxGetExpected(ssModelLisrel, 'means'),
 
 omxCheckWarning(
 	omxCheckError(ssDataLisrel <- mxGenerateData(ssModelLisrel,200),
-		"mean and sigma have non-conforming size"),
+		"Cannot generate data from model 'lisrel' where means are not specified"),
 	"Means requested, but model has no means.\nAdd appropriate TX, TY, KA, and/or KA matrices to get real means."
 )
 # Causes error/warning
