@@ -1,3 +1,19 @@
+#
+#   Copyright 2007-2017 The OpenMx Project
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+# 
+#        http://www.apache.org/licenses/LICENSE-2.0
+# 
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
+
+
 # ---------------------------------------------------------------------
 # Program: RAM-3Factor-12Indicators.R
 #  Author: Steven M. Boker
@@ -104,7 +120,7 @@ threeFactorOrthogonal <- mxModel("threeFactorOrthogonal",
     mxPath(from="one", to=c(latents), 
            arrows=1, free=TRUE, values=.1, 
            labels=meanLabels),
-    mxCI(c('A', 'S')),
+    mxCI(c('A', 'S'), boundAdj=FALSE),
     mxData(observed=cov(YMatrix), means=apply(YMatrix, 2, mean), 
 	numObs=nrow(YMatrix), type="cov")
 )
