@@ -31,8 +31,7 @@ require(OpenMx)
 #load("wlsTest1.RData")
 
 f1 <- ordered(c("a","b"), levels=c("a","b"))
-f1 <- omxCheckWarning(ordered(f1, levels=c("b"), exclude="a"),
-                      "NAs introduced by coercion")
+f1 <- ordered(f1, levels=c("b"), exclude="a")
 
 f2 <- mxFactor(c("a","b"), levels=c("a","b"))
 f2 <- omxCheckWarning(mxFactor(f2, levels=c("b"), exclude="a"), NA)
