@@ -138,7 +138,12 @@ SEXP dtmvnorm_marginal2(SEXP Rxq, SEXP Rxr, SEXP Rq, SEXP Rr,
 	const Map<VectorXd> upper(as<Map<VectorXd> >(Rupper));
 	VectorXd density(4);
 
-	_dtmvnorm_marginal2(NA_REAL, xq, xr, qq, rr, sigma, lower, upper, density);
+	omxState *globalState = new omxState;
+	std::vector<double> startingValues;
+	FitContext *fc = new FitContext(globalState, startingValues);
+	_dtmvnorm_marginal2(fc, NA_REAL, xq, xr, qq, rr, sigma, lower, upper, density);
+	delete fc;
+	delete globalState;
 
 	return Rcpp::wrap(density);
 }
@@ -156,7 +161,12 @@ SEXP dtmvnorm_marginal(SEXP Rxn, SEXP Rn, SEXP Rsigma, SEXP Rlower, SEXP Rupper)
 	const Map<VectorXd> upper(as<Map<VectorXd> >(Rupper));
 	VectorXd density(2);
 
-	_dtmvnorm_marginal(NA_REAL, xn, nn, sigma, lower, upper, density);
+	omxState *globalState = new omxState;
+	std::vector<double> startingValues;
+	FitContext *fc = new FitContext(globalState, startingValues);
+	_dtmvnorm_marginal(fc, NA_REAL, xn, nn, sigma, lower, upper, density);
+	delete fc;
+	delete globalState;
 
 	return Rcpp::wrap(density);
 }
@@ -173,7 +183,12 @@ SEXP mtmvnorm(SEXP Rsigma, SEXP Rlower, SEXP Rupper)
 
 	VectorXd tmean;
 	MatrixXd tcov;
-	_mtmvnorm(NA_REAL, sigma, fullLower, fullUpper, tmean, tcov);
+	omxState *globalState = new omxState;
+	std::vector<double> startingValues;
+	FitContext *fc = new FitContext(globalState, startingValues);
+	_mtmvnorm(fc, NA_REAL, sigma, fullLower, fullUpper, tmean, tcov);
+	delete fc;
+	delete globalState;
 
 	omxManageProtectInsanity mpi;
 	MxRList result;
@@ -182,7 +197,7 @@ SEXP mtmvnorm(SEXP Rsigma, SEXP Rlower, SEXP Rupper)
 	return result.asR();
 }
 
-void omxSadmvnWrapper(int numVars, 
+void omxSadmvnWrapper(FitContext *fc, int numVars, 
 	double *corList, double *lThresh, double *uThresh, int *Infin, double *likelihood, int *inform)
 {
 	// Eigen::Map< Eigen::ArrayXd > elt(lThresh, numVars);
@@ -204,7 +219,6 @@ void omxSadmvnWrapper(int numVars,
    	//	Error	&double		On return: absolute real Rf_error, 99% confidence
    	//	Value	&double		On return: evaluated value
    	//	Inform	&int		On return: 0 = OK; 1 = Rerun, increase MaxPts; 2 = Bad input
-   	// TODO: Separate block diagonal covariance matrices into pieces for integration separately
    	double Error;
 	double absEps = Global->absEps;
 	double relEps = Global->relEps;
@@ -222,6 +236,8 @@ void omxSadmvnWrapper(int numVars,
    	F77_CALL(sadmvn)(&numVars, lThresh, uThresh, Infin, corList, &MaxPts, 
 		&absEps, &relEps, &Error, likelihood, inform, &fortranThreadId);
 
+	if (fc) fc->recordOrdinalRelativeError(Error / *likelihood);
+
    	if (0) {
    		char infinCodes[3][20];
    		strcpy(infinCodes[0], "(-INF, upper]");
@@ -247,7 +263,7 @@ static SEXP has_NPSOL()
 
 static SEXP has_openmp()
 {
-#if defined(_OPENMP) && WANT_OPENMP
+#if defined(_OPENMP)
 	bool opm = true;
 #else
 	bool opm = false;
@@ -350,7 +366,7 @@ static void readOpts(SEXP options, int *numThreads, int *analyticGradients)
 			} else if(matchCaseInsensitive(nextOptionName, "debug protect stack")) {
 				friendlyStringToLogical(nextOptionName, rawValue, &Global->debugProtectStack);
 			} else if(matchCaseInsensitive(nextOptionName, "Number of Threads")) {
-#if defined(_OPENMP) && WANT_OPENMP
+#ifdef _OPENMP
 				*numThreads = atoi(nextOptionValue);
 				if (*numThreads < 1) {
 					Rf_warning("Computation will be too slow with %d threads; using 1 thread instead", *numThreads);
@@ -636,6 +652,8 @@ SEXP omxBackend2(SEXP constraints, SEXP matList,
 				result.add("fitUnits", units);
 			}
 			result.add("Minus2LogLikelihood", Rf_ScalarReal(fc->fit));
+			result.add("maxRelativeOrdinalError",
+				   Rf_ScalarReal(fc->getOrdinalRelativeError()));
 		}
 		if (fc->wanted & FF_COMPUTE_BESTFIT) {
 			result.add("minimum", Rf_ScalarReal(fc->fit));
@@ -766,7 +784,7 @@ void R_init_OpenMx(DllInfo *info) {
 	// There is no code that will change behavior whether openmp
 	// is set for nested or not. I'm just keeping this in case it
 	// makes a difference with older versions of openmp. 2012-12-24 JNP
-#if defined(_OPENMP) && _OPENMP <= 200505 && WANT_OPENMP
+#if defined(_OPENMP) && _OPENMP <= 200505
 	omp_set_nested(0);
 #endif
 }
